@@ -564,7 +564,7 @@ on_email_cb (BjbMainToolbar *self,
 {
   g_return_if_fail (self->note);
 
-  on_email_note_callback (menu_item, self->note);
+  on_email_note_callback (self->note);
 }
 
 static void
@@ -637,8 +637,8 @@ bjb_main_toolbar_reset (BjbMainToolbar *self)
   gtk_widget_show (self->select_button);
   gtk_widget_show (self->search_button);
   gtk_widget_show (self->new_button);
+  gtk_widget_show (self->main_button);
 
-  gtk_widget_hide (self->main_button);
   gtk_widget_hide (self->back_button);
   gtk_widget_hide (self->color_button);
   gtk_widget_hide (self->empty_button);
@@ -918,7 +918,7 @@ bjb_main_toolbar_class_init (BjbMainToolbarClass *klass)
 
   g_object_class_install_properties (object_class, NUM_PROPERTIES, properties);
 
-  gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/bijiben/ui/main-toolbar.ui");
+  gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/Notes/ui/main-toolbar.ui");
 
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, button_stack);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, new_button);
